@@ -1,4 +1,3 @@
-
 import socket
 import struct
 from mcclient.address import Address
@@ -29,7 +28,7 @@ class BedrockSLPClient:
         return BedrockResponse(self.hostname, self.port, res)
 
     
-    def _request_status(self):
+    def _request_status(self): # needs an update (https://wiki.vg/Raknet_Protocol#Unconnected_Ping)
         sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         sock.settimeout(self.timeout)
 
